Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Cloud Map.

Actions, resources, and condition keys for AWS Cloud Map - Service Authorization Reference

# Actions, resources, and condition keys for AWS Cloud Map

AWS Cloud Map (service prefix: `servicediscovery` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Cloud Map
- Resource types defined by AWS Cloud Map
- Condition keys for AWS Cloud Map

## Actions defined by AWS Cloud Map

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateHttpNamespace | Creates an HTTP namespace. | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreatePrivateDnsNamespace | Creates a private namespace based on DNS, which will be visible only inside a specified Amazon VPC. | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreatePublicDnsNamespace | Creates a public namespace based on DNS, which will be visible on the internet. | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateService | Creates a service. | Write | namespace* |  |
| servicediscovery:NamespaceArn aws:TagKeys aws:RequestTag/${TagKey} |
DeleteNamespace | Deletes a specified namespace. | Write | namespace* |  |
DeleteService | Deletes a specified service. | Write | service* |  |
DeregisterInstance | Deletes the records and the health check, if any, that Amazon Route 53 created for the specified instance. | Write | service* |  |
| servicediscovery:ServiceArn |
DiscoverInstances | Discovers registered instances for a specified namespace and service. | Read |  | servicediscovery:NamespaceName servicediscovery:ServiceName |
GetInstance | Gets information about a specified instance. | Read |  | servicediscovery:ServiceArn |
GetInstancesHealthStatus | Gets the current health status (Healthy, Unhealthy, or Unknown) of one or more instances. | Read |  | servicediscovery:ServiceArn |
GetNamespace | Gets information about a namespace. | Read | namespace* |  |
GetOperation | Gets information about a specific operation. | Read |  |  |
GetService | Gets the settings for a specified service. | Read | service* |  |
ListInstances | Gets summary information about the instances that were registered with a specified service. | List |  | servicediscovery:ServiceArn |
ListNamespaces | Gets information about the namespaces. | List |  |  |
ListOperations | Lists operations that match the criteria that you specify. | List |  |  |
ListServices | Gets settings for all the services that match specified filters. | List |  |  |
ListTagsForResource | Lists tags for the specified resource. | List |  |  |
RegisterInstance | Registers an instance based on the settings in a specified service. | Write | service* |  |
| servicediscovery:ServiceArn |
TagResource | Adds one or more tags to the specified resource. | Tagging |  | aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Removes one or more tags from the specified resource. | Tagging |  | aws:TagKeys aws:RequestTag/${TagKey} |
UpdateInstanceCustomHealthStatus | Updates the current health status for an instance that has a custom health check. | Write |  | servicediscovery:ServiceArn |
UpdateService | Updates the settings in a specified service. | Write | service* |  |

## Resource types defined by AWS Cloud Map

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
namespace | `arn:$ { Partition}:servicediscovery:$ { Region}:$ { Account}:namespace/$ { NamespaceId}` | aws:ResourceTag/${TagKey}
service | `arn:$ { Partition}:servicediscovery:$ { Region}:$ { Account}:service/$ { ServiceId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Cloud Map

AWS Cloud Map defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on the tags associated with the resource | String
aws:TagKeys | Filters actions based on the tag keys that are passed in the request | String
servicediscovery:NamespaceArn | A filter that lets you get objects by specifying the Amazon Resource Name (ARN) for the related namespace. | String
servicediscovery:NamespaceName | A filter that lets you get objects by specifying the name of the related namespace. | String
servicediscovery:ServiceArn | A filter that lets you get objects by specifying the Amazon Resource Name (ARN) for the related service. | String
servicediscovery:ServiceName | A filter that lets you get objects by specifying the name of the related service. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.